==> tecfy_core_package-0.0.4.tar.gz: lib/controllers/entity/entity_filter.controller.dart <==
part of tecfy_core_client_package;

class EntityFilterController extends BaseController{
  
  EntityService _service;
  String entityName;
  List<Property> properties;
  List<dynamic> data;
  String titleField;
  String subTitleField;
  String tailField;
  
  EntityFilterController(State<StatefulWidget> state,this.entityName,this.properties) : super(state){

    _service = EntityService();
    print('-------------- EntityFilterController => $entityName');
    // entity = EntityService.entities[entityName];
    // print(entity);
    var props = properties.where((p)=>p.isGrid).toList();
    titleField = props.length > 0 ? lowerFirst(props[0].dbName) : '';
    print(titleField);
    subTitleField = props.length > 1 ? lowerFirst(props[1].dbName) : '';
    print(subTitleField);
    tailField = props.length > 2 ? lowerFirst(props[2].dbName) : '';
    print(tailField);
    if(tailField.isEmpty && subTitleField.isNotEmpty)
    {
      tailField = subTitleField;
      subTitleField ='';
    }
    //loadFromServer();
  }

  get hasPhoto =>  properties.any((d)=>d.propertyType== PropertyTypes.File && (d as PropertyFile).isImage == true);
  

  // loadFromServer()async{
  //   var result = await _service.getData(entity.dbName);

  //   if(!result.success){
  //     data = [];
  //     // showMessage('خطأ اثناء الحصول على البيانات');
  //     result.showMessage(context);
  //   }else data = result.data;

  //   setState();
    
  // }

  // Future onRefresh(){
  //   return loadFromServer();
  // }

  // onAdd(){
  //   AppNavigator.navigateTo(context, ()=>EntityFormPage(entity.dbName), animationType: AnimationTypes.slideUp);
  // }
  // onUpdate(d){
  //   AppNavigator.navigateTo(context, ()=>EntityFormPage(entity.dbName,d), animationType: AnimationTypes.slideUp);
  // }
  // onDelete(d)async{
    
  //   if(await confirmMessage('هل انت متاكد من الحذف؟')){
  //     var result = await EntityService().delete(entity.dbName,d['id']);
  //     if(result.success){
  //       showMessage('تم الحذف بنجاح',type: MessageType.info);
  //       loadFromServer();
  //     }else{
  //       showMessage('خطأ اثناء الحذف',type: MessageType.error);
  //     }
  //   }

  // }

  lowerFirst(String s){
    return '${s[0].toLowerCase()}${s.substring(1)}';
  }

  String get getPhotoDataPropName => '${properties.firstWhere((d)=>d.isImage).dbName}Id';
  
}

==> tecfy_core_package-0.1.17.tar.gz: lib/controllers/entity/entity_filter.controller.dart <==
part of tecfy_core_client_package;

class EntityFilterController extends BaseController{
  
  //EntityService _service;
  String entityName;
  List<Property> properties;
  List<dynamic> data;
  String titleField;
  String subTitleField;
  String tailField;
  
  EntityFilterController(State<StatefulWidget> state,this.entityName,this.properties) : super(state){

    //_service = EntityService();
    print('-------------- EntityFilterController => $entityName');
    // entity = EntityService.entities[entityName];
    // print(entity);
    var props = properties.where((p)=>p.isGrid).toList();
    titleField = props.length > 0 ? lowerFirst(props[0].dbName) : '';
    print(titleField);
    subTitleField = props.length > 1 ? lowerFirst(props[1].dbName) : '';
    print(subTitleField);
    tailField = props.length > 2 ? lowerFirst(props[2].dbName) : '';
    print(tailField);
    if(tailField.isEmpty && subTitleField.isNotEmpty)
    {
      tailField = subTitleField;
      subTitleField ='';
    }
    //loadFromServer();
  }

  get hasPhoto =>  properties.any((d)=>d.propertyType== PropertyTypes.File && (d as PropertyFile).isImage == true);
  

  // loadFromServer()async{
  //   var result = await _service.getData(entity.dbName);

  //   if(!result.success){
  //     data = [];
  //     // showMessage('خطأ اثناء الحصول على البيانات');
  //     result.showMessage(context);
  //   }else data = result.data;

  //   setState();
    
  // }

  // Future onRefresh(){
  //   return loadFromServer();
  // }

  // onAdd(){
  //   AppNavigator.navigateTo(context, ()=>EntityFormPage(entity.dbName), animationType: AnimationTypes.slideUp);
  // }
  // onUpdate(d){
  //   AppNavigator.navigateTo(context, ()=>EntityFormPage(entity.dbName,d), animationType: AnimationTypes.slideUp);
  // }
  // onDelete(d)async{
    
  //   if(await confirmMessage('هل انت متاكد من الحذف؟')){
  //     var result = await EntityService().delete(entity.dbName,d['id']);
  //     if(result.success){
  //       showMessage('تم الحذف بنجاح',type: MessageType.info);
  //       loadFromServer();
  //     }else{
  //       showMessage('خطأ اثناء الحذف',type: MessageType.error);
  //     }
  //   }

  // }

  lowerFirst(String s){
    return '${s[0].toLowerCase()}${s.substring(1)}';
  }

  String get getPhotoDataPropName => '${properties.firstWhere((d)=>d.isImage).dbName}Id';
  
}
